@@ -13,7 +13,7 @@ use Digest::MD5 qw(md5_hex);
 use Errno;
 use Data::Dumper;
 our $AUTOLOAD;
-*VERSION = \'2.0.18';
+*VERSION = \'2.1.2.1';
 
 use constant { OK => 0, WARNING => 1, CRITICAL => 2, UNKNOWN => 3 };
 
@@ -636,6 +636,7 @@ sub load_my_extension {
     }
     my $plugin_name = $Monitoring::GLPlugin::pluginname;
     $plugin_name =~ /check_(.*?)_health/;
+    my $deprecated_class = "DBD::".(uc $1)."::Server";
     $plugin_name = "Check".uc(substr($1, 0, 1)).substr($1, 1)."Health";
     foreach my $libpath (split(":", $self->opts->get("with-mymodules-dyn-dir"))) {
       foreach my $extmod (glob $libpath."/".$plugin_name."*.pm") {
@@ -658,7 +659,8 @@ sub load_my_extension {
     my $original_init = $self->can("init");
     $self->compatibility_class() if $self->can('compatibility_class');
     bless $self, "My$class";
-    $self->compatibility_methods() if $self->can('compatibility_methods');
+    $self->compatibility_methods() if $self->can('compatibility_methods') &&
+        $self->isa($deprecated_class);
     if ($self->isa("Monitoring::GLPlugin")) {
       my $new_init = $self->can("init");
       if ($new_init == $original_init) {
